==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Pemalam %1 tidak sepenuhnya serasi dengan sistem.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Buang</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Tetapan Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Hidupkan</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Tetapan Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 bersambung</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Menyambung...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Dimatikan</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Tambah bentangan papan kekunci</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Tarikhwaktu</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Waktu 12-jam</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Waktu 24-jam</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Tetapan waktu</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Benarkan rangkaian</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Lumpuhkan rangkaian</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Tetapan rangkaian</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Anda pasti mahu kosongkan %1 item?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Tindakan ini tidak dapat dipulihkan</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Peranti tidak diketahui</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volum tidak diketahui</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Cakera</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Tanggalkan semua</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Pelancar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Mod Berfesyen</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mod Efisyen</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Teratas</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bawah</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Kiri</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Kanan</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Kekal Ditunjukkan</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Kekal Tersembunyi</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Sembunyi Pintar</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mod</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Lokasi</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Pemalam</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Pandangan Tugas-berbilang</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Tanggal</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Lumpuhkan sambungan berwayar</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Benarkan sambungan berwayar</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Lumpuhkan sambungan tanpa wayar</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Benarkan sambungan tanpa wayar</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Lumpuhkan rangkaian</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Benarkan rangkaian</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Tetapan rangkaian</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Peranti dilumpuhkan</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Sambungan tanpa wayar: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Sambungan berwayar: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Tidak bersambung</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Menyambung</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Bersambung tetapi tiada capaian Internet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kabel rangkaian telah dicabut</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rangkaian Tanpa Wayar</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rangkaian Berwayar</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Rangkaian</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rangkaian Berwayar</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rangkaian Berwayar %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Atas Papan</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Kuasa</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Tetapan kuasa</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapasiti %1, %2 min berbaki</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapasiti %1, %2 j %3 min berbaki</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Mengecas %1, %2 min sehingga penuh</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Mengecas %1, %2 j %3 min sehingga penuh</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Dicas</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapasiti %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Mengecas %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapasiti %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapasiti %1, sepenuhnya dicas</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Tunjuk Atas Meja</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Tanggal</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Kuasa</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Tangguh</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernasi</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kunci</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Daftar  keluar</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Tukar akaun</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Tetapan kuasa</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>But semula</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Peranti</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Suarakan</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Senyap</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Tetapan bunyi</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volum %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Bunyi</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Tong Sampah</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Fail %1- disampahkan</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Fail %1- disampahkan</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Kosong</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Talam Sistem</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rangkaian Tanpa Wayar</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Sambungan Tanpa Wayar %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.38.orig.tar.xz: dde-dock-5.5.38/translations/dde-dock_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Pemalam %1 tidak sepenuhnya serasi dengan sistem.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Hidupkan</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Buang</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Tetapan Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Hidupkan</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Tetapan Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 bersambung</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Menyambung...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Dimatikan</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Tambah bentangan papan kekunci</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Tarikhwaktu</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Waktu 12-jam</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Waktu 24-jam</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Tetapan waktu</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Anda pasti mahu kosongkan %1 item?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Tindakan ini tidak dapat dipulihkan</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Peranti tidak diketahui</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volum tidak diketahui</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Cakera</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Tanggalkan semua</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Pelancar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Keluar dari Mod Selamat</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Labuh - Mod Selamat</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Labuh dalam mod selamat, sila keluar dahulu supaya dapat dipaparkan dengan baik</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Mod Berfesyen</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mod Efisyen</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Teratas</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bawah</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Kiri</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Kanan</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Kekal Ditunjukkan</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Kekal Tersembunyi</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Sembunyi Pintar</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mod</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Lokasi</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Saiz</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Paparan Berbilang</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Mod fesyen</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Mod efisyen</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mod</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Teratas</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bawah</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Kiri</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Kanan</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Lokasi</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Kekal tersembunyi</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Sembunyi pintar</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Kecil</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Besar</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Atas skrin yang mana kursor berada</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Hanya dalam skrin utama</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Pandangan Tugas-berbilang</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Tanggal</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Atas Papan</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Kuasa</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Tetapan kuasa</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapasiti %1, %2 min berbaki</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapasiti %1, %2 j %3 min berbaki</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Mengecas %1, %2 min sehingga penuh</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Mengecas %1, %2 j %3 min sehingga penuh</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapasiti %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Mengecas %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapasiti %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapasiti %1, sepenuhnya dicas</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Labuh</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Tunjuk Atas Meja</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Tanggal</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Kuasa</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Tangguh</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernasi</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kunci</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Daftar  keluar</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Tukar akaun</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Tetapan kuasa</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>But semula</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Peranti</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Suarakan</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Senyap</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Tetapan bunyi</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volum %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Bunyi</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Tong Sampah</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Fail %1- disampahkan</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Fail %1- disampahkan</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Alih ke Tong Sampah</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Kosong</translation>
    </message>
</context>
</TS>
